@@ -16,7 +16,7 @@ test_that("Test whether results from newey_west_cpp function coincide
           # Newey West from lpirfs
            nw_lpirfs   <- newey_west(y, x, nlag)[[2]]
 
-           testthat::expect_equal(nw_sandwich, nw_lpirfs, tolerance=1e-6, ignore_attr = T)
+           testthat::expect_equal(nw_sandwich, nw_lpirfs, tolerance=1e-10, ignore_attr = T)
 
             } )
 
@@ -44,6 +44,31 @@ test_that("Test whether prewhitening results coincide with results from sandwich
 
             nw_lpirfs       <- newey_west_pw(resid_pw, xpxi, D_mat, nlag)[[1]]
 
-            testthat::expect_equal(nw_sandwich, nw_lpirfs, tolerance=1e-6, ignore_attr = T)
+            testthat::expect_equal(nw_sandwich, nw_lpirfs, tolerance=1e-10, ignore_attr = T)
 
           } )
+
+
+test_that("Test whether Newey-West 2SLS cov coincides with sandwich and AER package", {
+
+  # Set seed for reproducibility
+  set.seed(123)
+
+  x <- matrix(rnorm(100), 100, 1)
+  z <- matrix(rnorm(100), 100, 1)
+  y <- matrix(rnorm(100))
+
+  # Step 2: 2SLS Estimation using ivreg from AER package
+  model_ivreg <- AER::ivreg(y ~ x | z)
+
+  # Step 3: Compute Newey-West Standard Errors
+  vcov_nw_2sls = summary(model_ivreg, vcov =  sandwich::NeweyWest(model_ivreg,
+                                                        lag = 1,
+                                                        prewhite = FALSE,
+                                                        adjust = F),
+                         df = Inf,
+                         diagnostics = TRUE)$vcov
+  testthat::expect_equal(newey_west_tsls(y, x, z, 1)[[2]], unname(vcov_nw_2sls), tolerance=1e-10)
+
+} )
+
